package com.ruoyi.web.controller.common;

import org.springframework.stereotype.Component;

import javax.annotation.PostConstruct;
import java.io.IOException;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.Executors;
import java.util.concurrent.ScheduledExecutorService;
import java.util.concurrent.TimeUnit;

@Component
public class ApiIdleMonitor {

    private static final long IDLE_THRESHOLD = 5 * 60 * 1000;
   // private static final long IDLE_THRESHOLD = 10000;
    private static final ConcurrentHashMap<String, Long> lastRequestTimeMap = new ConcurrentHashMap<>();
    private static final ScheduledExecutorService scheduler = Executors.newSingleThreadScheduledExecutor();

    @PostConstruct
    public void init() {
        scheduler.scheduleAtFixedRate(this::checkIdleApis, 1, 5, TimeUnit.MINUTES);//TimeUnit.MINUTES)
    }

    public static void updateRequestTime(String apiPath) {
        lastRequestTimeMap.put(apiPath, System.currentTimeMillis());
    }

    private void checkIdleApis() {
        long currentTime = System.currentTimeMillis();
        lastRequestTimeMap.forEach((apiPath, lastTime) -> {
            if (currentTime - lastTime > IDLE_THRESHOLD) {
                try {
                    lastRequestTimeMap.remove(apiPath);
                    ProcessBuilder pb = new ProcessBuilder("systemctl", "stop", "clash");
                    pb.redirectErrorStream(true);
                    Process process = pb.start();
                    process.waitFor();
                    lastRequestTimeMap.remove(apiPath);
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
        });
    }


}